remove(list=ls())     # Remove all variables from memory
require(lmerTest)     # For lmer()
require(car)          # For Anova (note the capital A)

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

cat("
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Analysis of the remaining cover taking change over time into account        #
# using Day as covariate:                                                     #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
")
Data1=read.csv(file="Figure 3 AB Raw data.csv", sep=",")
#View(Data1)

Data1$Plot=factor(Data1$Plot)
Data1$Block=factor(Data1$Block)
Data1$Band=factor(Data1$Band)
Data1$Cluster=factor(Data1$Cluster)
Data1$Month=factor(Data1$Month)

# --- Statistical Analysis ----------------------------------------------------

# We use Month as random factor, as seasonal effect were not a explicit question
# But we are interested in potential differences between months, so we're going for m1.2.
m1.1<-lmer(Cover~Band*Cluster*Day+(1|Month)+(1|Block2/Plot), data=Data1)
OpenWindow(Width=7,Height=5)
qqnorm(resid(m1.1)); 
qqline(resid(m1.1), col = 2,lwd=2,lty=2)
print( shapiro.test(resid(m1.1)) )# Not normally distributed, but doesn't deviate badly either, especially given the large amount of data

cat("
=> We use Month as random factor, as seasonal effect were not a explicit question
=> But we are interested in potential differences between months, so we're going for m1.2.
")

print(anova(m1.1)) # Anova table from the glmm model with Satterthwaitte correction of DF
print(rand(m1.1)) # Tests significance of the random effect term

# --- Statistical analysis of the decrease per day ----------------------------

# Here we test only for the effect of Period on the Cover decrease, as a basis
# for our statement that the lossrate declines later in the experiment.

Data3=read.csv(file="Figure 3 CD Raw data.csv", sep=",") 

Data3$Name=factor(Data3$Name)
Data3$Plot=factor(Data3$Plot)
Data3$Block=factor(Data3$Block)
Data3$Block2=factor(Data3$Block2)
Data3$Band=factor(Data3$Band)
Data3$Cluster=factor(Data3$Cluster)
Data3$Month=factor(Data3$Month)
Data3$Period=factor(Data3$Period)

# lmer version with month and block as random factors:
Decr2<-lmer(LinDecr~Band*Cluster*Period+(1|Month)+(1|Block2/Plot), data=Data3)
OpenWindow(Width=7,Height=5)
qqnorm(resid(Decr2)); qqline(resid(Decr2), col = 2,lwd=2,lty=2)
print(shapiro.test(resid(Decr2)))
print(anova(Decr2))
print(rand(Decr2))

