remove(list=ls())     # Remove all variables from memory
library(gplots)

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Plotting the remaining cover for the June and October experiments           # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #


Data1=read.csv(file="Figure 3 AB Raw data.csv", sep=",")
#View(Data1)

Data1$Plot=factor(Data1$Plot)
Data1$Block=factor(Data1$Block)
Data1$Band=factor(Data1$Band)
Data1$Cluster=factor(Data1$Cluster)
Data1$Month=factor(Data1$Month)

# --- Preparing the data for analysis -----------------------------------------

TreatmentNames = c("Banded\nClustered", 
                   "Banded\nNot clustered", 
                   "Not banded\nClustered",
                   "Not banded\nNot clustered")

Treatment=factor(Data1$Treat,
                 levels = c("B-A","B-NA","NB-A","NB-NA"),
                 labels = TreatmentNames)

# --- Setting up the data for the first figure --------------------------------

Left = Data1$Cover
Band=factor(Data1$Band)
Cluster=factor(Data1$Cluster)
Month = Data1$Month

stderr <- function(x) sqrt(var(x,na.rm=T)/length(which(!is.na(x))))

# Creating the data and catagorial variables
Cats=list(Treatment,Month)
Value=tapply(Left,Cats,mean)
STE=tapply(Left,Cats,stderr)

# --- Figure 3 A and B  -------------------------------------------------------
# OpenWindow(Width=5,Height=6.5)
OpenWindow(Width=5.5,Height=7)
par(mfrow=c(2,1), mar=c(2,5,2,2)+0.1)
Ymin=50

Colors=c("#333333", "#666666", "#999999", "#cccccc")

barplot2(Value, beside=TRUE,
         plot.ci = TRUE, ylim=c(Ymin,100),
         ci.l = (Value-STE), ci.u = (Value+STE),
         ylab='Percentage remaining',xpd=F,space=c(0.1,1),
         col=Colors, axisnames=F)

mtext(text="A: June", line=-0.9, adj=0.05)
mtext(text="B: October", line=-0.9, adj=0.68)

LineWidth=5

S=0.0

lines(c(1,5.3),  c(Ymin+S,Ymin+S), cex=LineWidth)
lines(c(6.3,10.6),  c(Ymin+S,Ymin+S), cex=LineWidth)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Plotting the calculated rate of decrease or the first 5 days                #
# and the remaining time.                                                     #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

Data2=read.csv(file="Figure 3 CD Raw data.csv")
#View(Data2)

Data2$Band=factor(Data2$Band)
Data2$Cluster=factor(Data2$Cluster)
Data2$Month=factor(Data2$Month)
Data2$Period=factor(Data2$Period)

# --- Preparing the data ------------------------------------------------------

Treatment=factor(Data2$Treat,
                 levels = c("B-A","B-NA","NB-A","NB-NA"),
                 labels = TreatmentNames)

Gone0_5  = subset(Data2,Month="June")
Gone5_11 = subset(Data2,Month="October")

Decr = -Data2$LinDecr

Cats=list(Treatment,Data2$Period)
Value= tapply(Decr,Cats,mean)
STE  = tapply(Decr,Cats,stderr)

# --- Figure 3 C and D --------------------------------------------------------

par(mar=c(4,5,0,2)+0.1)

barplot2(Value, beside=TRUE,
         plot.ci = TRUE, ylim=c(0,12),
         ci.l = (Value-STE), ci.u = (Value+STE),
         ylab='Decrease per day (%)',xpd=F, space=c(0.1,1),
         col=Colors, axisnames=F)

mtext(side=3,line=-1, adj=0.045, text="C: First 5 days")
mtext(side=3,line=-1, adj=0.88,   text="D: Remaining period")

par(mfrow=c(1,1),mar=c(0,0,4,0)+0.1)

S=-1.85

lines(c(1,5.3),  c(S,S), cex=LineWidth)
lines(c(6.3,10.6),  c(S,S), cex=LineWidth)

legend(x=-1.5,y=-2.5, fill=Colors[1:4], legend=TreatmentNames[1:4], 
       bty="n", horiz=T, cex=0.9)
