remove(list=ls())     # Remove all variables from memory
require(car)          # For Anova (note the capital A)
require(MASS)         # For glm.nb

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

cat("
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Figure 4A: Analyzing the number of mussels in clusters                      #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
\n")

DataClump=read.csv(file="Figure 4A Raw Data.csv")
#View(DataClump)

DataClump$Bands=factor(DataClump$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataClump$Cluster=factor(DataClump$Cluster,
                         levels = c(1,2),
                         labels = c("Not clustered", "Clustered"))
DataClump$Location=factor(DataClump$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))

DataClump$TreatNr = (DataClump$Bands=="Not banded")*2 + (DataClump$Cluster=="Not clustered")*1+1

TreatmentNames = c("Banded\nClustered", 
                   "Banded\nNot clustered", 
                   "Not banded\nClustered",
                   "Not banded\nNot clustered")

DataClump$Treatment=factor(DataClump$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

# --- The statistics for figure 4A --------------------------------------------

cat("First, Analysis with GLM using a poison distribution : ")
m1.1<-glm(Clusters.size~Bands*Cluster*Location, data=DataClump, family="poisson")
#print(summary(m1.1)) # severe overdisperion
cat(paste("AIC : ", AIC(m1.1), "\n"))

cat("Second, Analysis with GLM using a normal distribution : ")
m1.2<-glm.nb(Clusters.size~Bands*Cluster*Location, data=DataClump)
#print(summary(m1.2)) # much better
cat(paste("AIC : ", AIC(m1.2), "\n")) 

cat("=> The normal distribution performs much better than poisson. \n")
cat("=> This is the one we use in the paper, see analysis below.\n\n")
print(Anova(m1.2)) 

cat("
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Figure 4B: Analyzing the number of loose mussels                            #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
\n")

DataLoose=read.csv(file="Figure 4B Raw Data.csv")
#View(DataLoose)

DataLoose$Bands=factor(DataLoose$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataLoose$Cluster=factor(DataLoose$Cluster,
                         levels = c(1,2),
                         labels = c("Not clustered", "Clustered"))
DataLoose$Location=factor(DataLoose$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))

DataLoose$TreatNr = (DataLoose$Bands=="Not banded")*2 + (DataLoose$Cluster=="Not clustered")*1+1

DataLoose$Treatment=factor(DataLoose$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

# --- The statistics for figure 4B --------------------------------------------

cat("--- With no transformation -----------------------------------------------------\n")
m2.1<-lm(Loose_Mussels~Bands*Cluster*Location, data=DataLoose)
print(shapiro.test(resid(m2.1)))
OpenWindow(Width=7,Height=5); qqPlot(m2.1, main="Untransformed data") 
print(leveneTest(m2.1))
cat("\n=> Need to transform, clearly\n")

cat("\n--- With Logatimic transformation ----------------------------------------------\n")
DataLoose$lgLM<-log(DataLoose$Loose_Mussels)
m2.2<-lm(lgLM~Bands*Cluster*Location, data=DataLoose)
print(shapiro.test(resid(m2.2)))
OpenWindow(Width=7,Height=5); qqPlot(m2.2, main="Log transformed data") 
print(leveneTest(m2.2))

cat("\n--- With square root transformation --------------------------------------------\n")
DataLoose$sqrtLM<-sqrt(DataLoose$Loose_Mussels)
m2.3<-lm(sqrtLM~Bands*Cluster*Location, data=DataLoose)
print(shapiro.test(resid(m2.3)))
OpenWindow(Width=7,Height=5); qqPlot(m2.3, main="Sqrt transformed data") 
print(leveneTest(m2.3))

cat("\nThis is the best transformation. We therefore used the analysis below in the paper\n\n")
print(Anova(m2.3))
