remove(list=ls())     # Remove all variables from memory
require(gplots)

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Figure 4A: Plotting and analyzing the number of mussels in clusters         #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

DataClump=read.csv(file="Figure 4A Raw Data.csv")
#View(DataClump)

DataClump$Bands=factor(DataClump$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataClump$Cluster=factor(DataClump$Cluster,
                         levels = c(1,2),
                         labels = c("Not clustered", "Clustered"))
DataClump$Location=factor(DataClump$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))

DataClump$TreatNr = (DataClump$Bands=="Not banded")*2 + (DataClump$Cluster=="Not clustered")*1+1

TreatmentNames = c("Banded\nClustered", 
                   "Banded\nNot clustered", 
                   "Not banded\nClustered",
                   "Not banded\nNot clustered")

DataClump$Treatment=factor(DataClump$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

stderr <- function(x) sqrt(var(x,na.rm=T)/length(which(!is.na(x))))

Cats=list(DataClump$Location,DataClump$Treatment)
Value=tapply(DataClump$Clusters.size, Cats,mean)
STE=tapply(DataClump$Clusters.size, Cats, stderr)

# --- Figure 4A : Cluster sizes -----------------------------------------
OpenWindow(Width=5.5,Height=7)
par(mfrow=c(2,1), mar=c(2,5,2,0.5)+0.1)
Ymin=0

Colors=c("#333333", "#cccccc")

barplot2(Value, beside=TRUE,
         plot.ci = TRUE, ylim=c(0,25),
         ci.l = (Value-STE), ci.u = (Value+STE),
         ylab='Clump size (Nr)',xpd=F,
         col=Colors, axisnames=F)

axis(side=1, at=c(2,5,8,11), labels=TreatmentNames, line=0.25, lty=0, cex.axis=0.9)

mtext(text="A", line=-0.9, adj=0.05)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Figure 4B: Plotting the number of loose mussels                             #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

DataLoose=read.csv(file="Figure 4B Raw Data.csv")
#View(DataLoose)

DataLoose$Bands=factor(DataLoose$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataLoose$Cluster=factor(DataLoose$Cluster,
                         levels = c(1,2),
                         labels = c("Not clustered", "Clustered"))
DataLoose$Location=factor(DataLoose$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))

DataLoose$TreatNr = (DataLoose$Bands=="Not banded")*2 + (DataLoose$Cluster=="Not clustered")*1+1

DataLoose$Treatment=factor(DataLoose$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

# --- Figure 4B ---------------------------------------------------------------

# Preparing the data and computing means and Standard Error
Cats=list(DataLoose$Location,DataLoose$Treatment)
Value=tapply(DataLoose$Loose_Mussels, Cats,mean)
STE=tapply(DataLoose$Loose_Mussels, Cats, stderr)

# Plotting the barplot
barplot2(Value, beside=TRUE,
         plot.ci = TRUE, ylim=c(0,20),
         ci.l = (Value-STE), ci.u = (Value+STE),
         ylab='Mussels not in a clump (%)',xpd=F,
         col=Colors, axisnames=F)

axis(side=1, at=c(2,5,8,11), labels=TreatmentNames, line=0.25, lty=0, cex.axis=0.9)

legend(x=2,y=19, fill=Colors, legend=c("Mesocosm experiment","Field experiment"), bty="n")

mtext(text="B", line=-0.9, adj=0.05)
