remove(list=ls())     # Remove all variables from memory
require(car)          # For Anova (note the capital A)

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Analyzing the movement speed of mussels in clusters.                        #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

DataSpeed=read.csv(file="Figure 5 Raw Data.csv")
#View(DataSpeed)

DataSpeed$Bands=factor(DataSpeed$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataSpeed$Clusters=factor(DataSpeed$Clusters,
                          levels = c(1,2),
                          labels = c("Not clustered", "Clustered"))
DataSpeed$Location=factor(DataSpeed$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))
DataSpeed$Substrate=factor(DataSpeed$Substrate,
                           levels = c(1,2),
                           labels = c("Stone", "Sand"))

DataSpeed$TreatNr = (DataSpeed$Bands=="Not banded")*2 + (DataSpeed$Clusters=="Not clustered")*1+1

TreatmentNames = c("Banded\nClustered", 
                   "Banded\nNot clustered", 
                   "Not banded\nClustered",
                   "Not banded\nNot clustered")

DataSpeed$Treatment=factor(DataSpeed$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

# --- Statistics --------------------------------------------------------------

cat("\n--- Testing for normality and homogeneity - Untransformed data\n")

m4.1<-lm(Speed~Bands*Clusters*Substrate, data=DataSpeed)
print(shapiro.test(resid(m4.1)))
OpenWindow(Width=7,Height=5); qqPlot(m4.1, main = "Untransformed data")
print(leveneTest(m4.1))

cat("\n--- Testing for normality and homogeneity - Log transformed data\n")

DataSpeed$logSpeed<-log(DataSpeed$Speed+1)
m4.2<-lm(logSpeed~Bands*Clusters*Substrate, data=DataSpeed)
print(shapiro.test(resid(m4.2)))
OpenWindow(Width=7,Height=5); qqPlot(m4.2, main = "Log transformed data") 
print(leveneTest(m4.2)) # Best transformation (also better than sqrt)

cat("\n--- Final analysis, using log-transformed data -----------------\n\n")

print(Anova(m4.2))
