remove(list=ls())     # Remove all variables from memory
on=1; off=0

require(gplots)

# Set this to the folder on your computer that contains the data
setwd("~/Dropbox/Revision PNAS/Revision PNAS 2/dePaoli et al - Data & Stats")

# Define a function that opens a window on either Mac or Windows (Linux users use X11)
OpenWindow = function (Width,Height) {
  if (Sys.info()["sysname"]=="Darwin"){  # (Darwin stands for a Mac computer)
    quartz(width=Width, height=Height)
  } else {
    windows(width = Width, height = Height)}
}

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Plotting the movement speed of mussels in clusters.                         #
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

# Conversion factor from cm per 180 min
PixConv=18 # to mm/min.

DataSpeed=read.csv(file="Figure 5 Raw Data.csv")
#View(DataSpeed)

DataSpeed$Bands=factor(DataSpeed$Bands, 
                       levels = c(1,2),
                       labels = c("Not banded", "Banded"))
DataSpeed$Clusters=factor(DataSpeed$Clusters,
                         levels = c(1,2),
                         labels = c("Not clustered", "Clustered"))
DataSpeed$Location=factor(DataSpeed$Location,
                          levels = c(1,2),
                          labels = c("Mesocosm", "Field"))
DataSpeed$Substrate=factor(DataSpeed$Substrate,
                           levels = c(1,2),
                           labels = c("Stone", "Sand"))

DataSpeed$TreatNr = (DataSpeed$Bands=="Not banded")*2 + (DataSpeed$Clusters=="Not clustered")*1+1

TreatmentNames = c("Banded\nClustered", 
                   "Banded\nNot clustered", 
                   "Not banded\nClustered",
                   "Not banded\nNot clustered")

DataSpeed$Treatment=factor(DataSpeed$TreatNr,
                           levels = c(1,2,3,4),
                           labels = TreatmentNames)

stderr <- function(x) sqrt(var(x,na.rm=T)/length(which(!is.na(x))))

Cats=list(DataSpeed$Substrate,DataSpeed$Treatment)
Value=tapply(DataSpeed$Speed/PixConv, Cats,mean)
STE=tapply(DataSpeed$Speed/PixConv, Cats, stderr)

# --- Figure for the end-of-experiment results --------------------------------
OpenWindow(Width=5.5,Height=3.5)
par(mfrow=c(1,1), mar=c(2,5,2,0.5)+0.1)

Colors=c("#333333", "#cccccc")

barplot2(Value, beside=TRUE,
         plot.ci = TRUE, ylim=c(0,0.4),
         ci.l = (Value-STE), ci.u = (Value+STE),
         ylab='Movement velocity (mm/min)',xpd=F,
         col=Colors, axisnames=F)

axis(side=1, at=c(2,5,8,11), labels=TreatmentNames, line=0.25, lty=0, cex.axis=0.9)

legend(x=4,y=0.4, fill=Colors, legend=c("Stone","Sand"), bty="n", horiz=T)
